@@ -16,6 +16,17 @@ setClass("BinomFamily",
 setClass("PoisFamily",
           contains = "L2ParamFamily")
 
+## neg.Binomial family
+setClass("NbinomFamily",
+          contains = "L2ParamFamily")
+
+## neg.Binomial family with size
+setClass("NbinomwithSizeFamily",
+          contains = "L2ParamFamily")
+## neg.Binomial family in different parametrization
+setClass("NbinomMeanSizeFamily",
+          contains = "L2ParamFamily")
+
 ## Gamma family
 setClass("GammaFamily",
           contains = "L2ParamFamily")
