@@ -91,13 +91,18 @@ setMethod("qqplot", signature(x = "ANY",
              with.legend = TRUE,  ## shall a legend be plotted
              legend.bg = "white", ## background for the legend
              legend.pos = "topleft", ## position for the legend
-             legend.cex = 0.8     ## magnification factor for the legend
+             legend.cex = 0.8,     ## magnification factor for the legend
+             legend.pref = "",     ## prefix for legend  text
+             legend.postf = "",    ## postfix for legend text
+             legend.alpha = alpha.CI ## nominal level of CI
     ){ ## return value as in stats::qqplot
 
     mc <- match.call(call = sys.call(sys.parent(1)))
     if(missing(xlab)) mc$xlab <- as.character(deparse(mc$x))
     if(missing(ylab)) mc$ylab <- as.character(deparse(mc$y))
     mcl <- as.list(mc)[-1]
+    mcl$withSweave <- NULL
+    mcl$mfColRow <- NULL
     force(x)
 
 
@@ -154,10 +159,10 @@ setMethod("qqplot", signature(x = "ANY",
     if (!withSweave){
            devNew(width = width, height = height)
     }
-    opar <- par("mfrow")
-    on.exit(do.call(par, list(mfrow=opar)))
+    opar <- par("mfrow", no.readonly = TRUE)
+    if(mfColRow) on.exit(do.call(par, list(mfrow=opar, no.readonly = TRUE)))
 
-    if(mfColRow) opar1 <- par(mfrow = c(1,1))
+    if(mfColRow) opar1 <- par(mfrow = c(1,1), no.readonly = TRUE)
 
     ret <- do.call(stats::qqplot, args=mcl)
 
@@ -198,7 +203,8 @@ setMethod("qqplot", signature(x = "ANY",
                   n, exact.sCI = exact.sCI, exact.pCI = exact.pCI,
                   nosym.pCI = nosym.pCI, with.legend = with.legend,
                   legend.bg = legend.bg, legend.pos = legend.pos,
-                  legend.cex = legend.cex)
+                  legend.cex = legend.cex, legend.pref = legend.pref,
+                  legend.postf = legend.postf, legend.alpha = legend.alpha)
        }
     }
     return(ret)
